# Examples

## Timeout

```python
{!../examples/timeout.py!}
```
```text
{!../output/timeout.txt!}
```

## Barrier

```python
{!../examples/barrier.py!}
```
```text
{!../output/barrier.txt!}
```

## Shared Resource

```python
{!../examples/resource.py!}
```
```text
{!../output/resource.txt!}
```

## FIFO Queue

```python
{!../examples/queue.py!}
```
```text
{!../output/queue.txt!}
```

## Priority Queue

```python
{!../examples/priqueue.py!}
```
```text
{!../output/priqueue.txt!}
```

## Interrupts

```python
{!../examples/interrupt.py!}
```
```text
{!../output/interrupt.txt!}
```

## AllOf

```python
{!../examples/allof.py!}
```
```text
{!../output/allof.txt!}
```

## FirstOf with Timeout

```python
{!../examples/firstof_timeout.py!}
```
```text
{!../output/firstof_timeout.txt!}
```

## FirstOf with Queue

```python
{!../examples/firstof_queue.py!}
```
```text
{!../output/firstof_queue.txt!}
```
